function merge(tbls)
	local res = {}
	for i,v in ipairs(tbls) do
		for i2,v2 in ipairs(v) do
			table.insert(res,v2)
		end
	end
	
	return res
end

function allExcept(tbls, except)
	local tomerge = {}
	for i,v in pairs(tbls) do
		if i~=except then
			table.insert(tomerge, v)
		end
	end
	return merge(tomerge)
end

--list of upgrades from created groups, hidden on planner, mfd; late activation
upgrades = {
	smallAirfield = {
		blue = {'blueInfantrySmall','blueArmor','blueAirDefense','blueAmmo'},
		red = {'redInfantrySmall','redAirDefense','redArmor','redAmmo'}
	},
	largeAirfield = {
		blue = {'blueInfantryLarge','blueNASAMS','blueAirDefense','blueAmmo','blueArmor'},
		red = {'redInfantryLarge','redArmor','redAmmo','redAirDefense','redArmor'}
	},
	farp = {
		blue = {'blueInfantrySmall'},
		red = {}
	},
	desert = {
		blue = {'blueInfantrySmall','blueArmor', 'blueAirDefense'},
		red = {'redInfantrySmall','redArmor', 'redAirDefense'}
	},
	desertEWR = {
		blue = {'blueInfantrySmall','blueArmor', 'blueAirDefense'},
		red = {'redInfantrySmall','redArmor', 'redAirDefense-1'}
	},
	smallSAMSite = {
		blue = {'blueHawk','blueInfantrySmall','blueAmmo','blueArmor','blueAmmo'},
		red = {'redSA2','redAmmo', 'redAmmo','redInfantrySmall','redArmor'}
	},
	largeSAMSite = {
		blue = {'bluePatriot','blueInfantryLarge','blueAmmo','blueArmor','blueInfantrySmall','blueAmmo'},
		red = {'redSA11','redAmmo', 'redAirDefense','redInfantryLarge','redArmor','redInfantrySmall'}
	},
	SA5SAMSite = {
		blue = {'bluePatriot','blueInfantryLarge','blueAmmo','blueArmor','blueInfantrySmall','blueAmmo'},
		red = {'redSA5','redAmmo', 'redAmmo','redInfantryLarge','redArmor','redInfantrySmall'}
	}
}

--list of waypoints with specific data for specials
flavor = {
	laughlin = 'WPT 1\nStart zone',
	farpdallas = 'WPT 2\nHelo start zone',
	jean = 'WPT 3\nHidden Easter Egg, destroy for 500 immediate credits',
	hendersonexec = 'WPT 4\n',
	bouldercity = 'WPT 5\nHidden Easter Egg, destroy for 500 immediate credits',
	hooverdam = 'WPT 6\nDestroy the two Redfor substations for 250 credits each',
	mccarranintl = 'WPT 7\n',
	nlasvegas = 'WPT 8\n',
	nellisafb = 'WPT 9\n',
	xray = 'WPT 10\n',
	alamocharlie = 'WPT 11\nDestroy all structures for 1000 credits\n',
	creech = 'WPT 12\n',
	farpperth = 'WPT 13\nHelo spawns',
	beatty = 'WPT 14\n',
	pahutemesa = 'WPT 15\n',
	groomlake = 'WPT 16\n',
	coyotecharlie = 'WPT 17\nEWR site\nDestroy for 500 credits',
	tonopahtestrng = 'WPT 18\nLarge SAM site',
	tonopah = 'WPT 19\n',
	mina = 'WPT 20\n',
	lincolncounty = 'WPT 21\n',
	farplondon = 'WPT 22\nHelo spawns',
	mesquite = 'WPT 23\n',
}

--persistence data
local filepath = 'Raiders_696CW_RedDawn_Foothold_NV.miz'
if lfs then 
	local dir = lfs.writedir()..'Missions/Saves/'
	lfs.mkdir(dir)
	filepath = dir..filepath
	env.info('Foothold - Save file path: '..filepath)
end

pathofFile = filepath

--list of zones with who owns them starting off and their level of items: 0 = neutral, 1 = red, 2 = blue
bc = BattleCommander:new(filepath, 10, 60)
zones = {
	laughlin = ZoneCommander:new({zone='Laughlin', side=2, level=5, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.laughlin}),
	farpdallas = ZoneCommander:new({zone='FARP Dallas', side=2, level=1, upgrades=upgrades.farp, crates={}, flavorText=flavor.farpdallas}),
	jean = ZoneCommander:new({zone='Jean', side=1, level=4, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.jean}),
	hendersonexec = ZoneCommander:new({zone='Henderson Executive', side=1, level=3, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.hendersonexec}),
	bouldercity = ZoneCommander:new({zone='Boulder City', side=1, level=3, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.bouldercity}),
	hooverdam = ZoneCommander:new({zone='Hoover Dam', side=1, level=3, upgrades=upgrades.desert, crates={}, flavorText=flavor.hooverdam, income=0.5}),
	mccarranintl = ZoneCommander:new({zone='McCarran International', side=1, level=4, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.mccarranintl}),
	nlasvegas = ZoneCommander:new({zone='N Las Vegas', side=1, level=3, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.nlasvegas}),
	nellisafb = ZoneCommander:new({zone='Nellis AFB', side=1, level=4, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.nellisafb}),
	xray = ZoneCommander:new({zone='X-Ray', side=1, level=3, upgrades=upgrades.desert, crates={}, flavorText=flavor.xray}),
	alamocharlie = ZoneCommander:new({zone='Alamo Charlie', side=1, level=3, upgrades=upgrades.desert, crates={}, flavorText=flavor.alamocharlie}),
	creech = ZoneCommander:new({zone='Creech', side=1, level=4, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.creech}),
	farpperth = ZoneCommander:new({zone='FARP Perth', side=0, level=1, upgrades=upgrades.farp, crates={}, flavorText=flavor.farpperth}),
	beatty = ZoneCommander:new({zone='Beatty', side=1, level=3, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.beatty}),
	pahutemesa = ZoneCommander:new({zone='Pahute Mesa', side=1, level=3, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.pahutemesa}),
	groomlake = ZoneCommander:new({zone='Groom Lake', side=1, level=4, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.groomlake}),
	coyotecharlie = ZoneCommander:new({zone='Coyote Charlie', side=1, level=3, upgrades=upgrades.desertEWR, crates={}, flavorText=flavor.coyotecharlie}),
	tonopahtestrng = ZoneCommander:new({zone='Tonopah Test Range', side=1, level=4, upgrades=upgrades.largeSAMSite, crates={}, flavorText=flavor.tonopahtestrng}),
	tonopah = ZoneCommander:new({zone='Tonopah', side=1, level=3, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.tonopah}),
	mina = ZoneCommander:new({zone='Mina', side=1, level=3, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.mina}),
	lincolncounty = ZoneCommander:new({zone='Lincoln County', side=1, level=6, upgrades=upgrades.SA5SAMSite, crates={}, flavorText=flavor.lincolncounty}),
	farplondon = ZoneCommander:new({zone='FARP London', side=0, level=1, upgrades=upgrades.farp, crates={}, flavorText=flavor.farplondon}),
	mesquite = ZoneCommander:new({zone='Mesquite', side=1, level=4, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.mesquite}),
}

-- add unit groups to zones
zones.farpdallas:addGroups({
	GroupCommander:new({name='farpdallasjeanResupply', mission='supply', targetzone='Jean'})
})

zones.hendersonexec:addGroups({
	GroupCommander:new({name='redhendersonjeanSurfAttack', mission='attack', targetzone='Jean', type='surface'})
})

zones.jean:addGroups({
	GroupCommander:new({name='redjeanlaughlinResupply', mission='supply', targetzone='Laughlin'}),
	GroupCommander:new({name='bluejeanlaughlinResupply', mission='supply', targetzone='Laughlin'}),
	GroupCommander:new({name='redjeanlaughlinAttack', mission='attack', targetzone='Laughlin'})
})

zones.bouldercity:addGroups({
	GroupCommander:new({name='redbouldercityPatrol', mission='patrol', targetzone='Boulder City'}),
	GroupCommander:new({name='redbouldercitylaughlinResupply', mission='supply', targetzone='Laughlin'}),
	GroupCommander:new({name='bluebouldercitylaughlinResupply', mission='supply', targetzone='Laughlin'}),
	GroupCommander:new({name='redbouldercitylaughlinAttack', mission='attack', targetzone='Laughlin'})
})

zones.hooverdam:addGroups({
	GroupCommander:new({name='bluehooverdammesquiteResupply', mission='supply', targetzone='Mesquite'}),
	GroupCommander:new({name='redhooverdammesquiteResupply', mission='supply', targetzone='Mesquite'}),
	GroupCommander:new({name='redhooverdambouldercitySurfAttack', mission='attack', targetzone='Boulder City', type='surface'})
})

zones.mccarranintl:addGroups({
	GroupCommander:new({name='redmccarranintljeanAttack', mission='attack', targetzone='Jean'}),
	GroupCommander:new({name='redmccarranintlhendersonexecAttack', mission='attack', targetzone='Henderson Executive'}),
	GroupCommander:new({name='redmccarranintljeanresupply', mission='supply', targetzone='Jean'}),
	GroupCommander:new({name='redmccarranintlhendersonexecResupply', mission='supply', targetzone='Henderson Executive'}),
	GroupCommander:new({name='redmccarranintlbouldercityResupply', mission='supply', targetzone='Boulder City'}),
	GroupCommander:new({name='redmccarranintlhooverdamResupply', mission='supply', targetzone='Hoover Dam'}),
	GroupCommander:new({name='bluemccarranintljeanresupply', mission='supply', targetzone='Jean'}),
	GroupCommander:new({name='bluemccarranintlhendersonexecResupply', mission='supply', targetzone='Henderson Executive'}),
	GroupCommander:new({name='bluemccarranintlbouldercityResupply', mission='supply', targetzone='Boulder City'}),
	GroupCommander:new({name='bluemccarranintlhooverdamResupply', mission='supply', targetzone='Hoover Dam'}),
	GroupCommander:new({name='redmccarranhendersonSurfAttack', mission='attack', targetzone='Henderson Executive', type='surface'})
})

zones.nlasvegas:addGroups({
	GroupCommander:new({name='rednlasvegasmccarranintlResupply', mission='supply', targetzone='McCarran International'}),
	GroupCommander:new({name='rednlasvegasnellisafbResupply', mission='supply', targetzone='Nellis AFB'}),
	GroupCommander:new({name='rednlasvegascreechResupply', mission='supply', targetzone='Creech'}),
	GroupCommander:new({name='bluenlasvegasmccarranintlResupply', mission='supply', targetzone='McCarran International'}),
	GroupCommander:new({name='bluenlasvegasnellisafbResupply', mission='supply', targetzone='Nellis AFB'}),
	GroupCommander:new({name='bluenlasvegascreechResupply', mission='supply', targetzone='Creech'}),
	GroupCommander:new({name='rednlasvegasmccarranSurfAttack', mission='attack', targetzone='McCarran International', type='surface'}),
	GroupCommander:new({name='rednlasvegasnellisafbSurfAttack', mission='attack', targetzone='Nellis AFB', type='surface'})
})

zones.nellisafb:addGroups({
	GroupCommander:new({name='rednellesafbPatrol', mission='patrol', targetzone='Nellis AFB'}),
	GroupCommander:new({name='rednellisafbbouldercityAttack', mission='attack', targetzone='Boulder City'}),
	GroupCommander:new({name='rednellisafbhooverdamAttack', mission='attack', targetzone='Hoover Dam'}),
	GroupCommander:new({name='rednellisafbmccarranintlAttack', mission='attack', targetzone='McCarran International'}),
	GroupCommander:new({name='rednellisafbmccarranintlResupply', mission='supply', targetzone='McCarran International'}),
	GroupCommander:new({name='rednellisafbnlasvegasResupply', mission='supply', targetzone='N Las Vegas'}),
	GroupCommander:new({name='rednellisafbxrayResupply', mission='supply', targetzone='X-Ray'}),
	GroupCommander:new({name='bluenellisafbmccarranintlResupply', mission='supply', targetzone='McCarran International'}),
	GroupCommander:new({name='bluenellisafbnlasvegasResupply', mission='supply', targetzone='N Las Vegas'}),
	GroupCommander:new({name='bluenellisafbxrayResupply', mission='supply', targetzone='X-Ray'}),
	GroupCommander:new({name='rednellismccarranSurfAttack', mission='attack', targetzone='McCarran International', type='surface'}),
	GroupCommander:new({name='rednellisafbbouldercitySurfAttack', mission='attack', targetzone='Boulder City', type='surface'})
})

zones.xray:addGroups({
	GroupCommander:new({name='redxraymesquiteResupply', mission='supply', targetzone='Mesquite'}),
	GroupCommander:new({name='bluexraymesquiteResupply', mission='supply', targetzone='Mesquite'}),
	GroupCommander:new({name='redxrayalamocharlieResupply', mission='supply', targetzone='Alamo Charlie'}),
	GroupCommander:new({name='bluexrayalamocharlieResupply', mission='supply', targetzone='Alamo Charlie'})
})

zones.creech:addGroups({
	GroupCommander:new({name='redcreechPatrol', mission='patrol', targetzone='Creech'}),
	GroupCommander:new({name='redcreechxrayAttack', mission='attack', targetzone='X-Ray'}),
	GroupCommander:new({name='bluecreechalamocharlieResupply', mission='supply', targetzone='Alamo Charlie'}),
	GroupCommander:new({name='bluecreechbeattyResupply', mission='supply', targetzone='Beatty'}),
	GroupCommander:new({name='redcreechalamocharlieResupply', mission='supply', targetzone='Alamo Charlie'}),
	GroupCommander:new({name='redcreechbeattyResupply', mission='supply', targetzone='Beatty'}),
	GroupCommander:new({name='redcreechxraySurfAttack', mission='attack', targetzone='X-Ray', type='surface'})
})

zones.beatty:addGroups({
	GroupCommander:new({name='redbeattyPatrol', mission='patrol', targetzone='Beatty'})
})

zones.pahutemesa:addGroups({
	GroupCommander:new({name='redpahutemesagroomlakeSurfAttack', mission='attack', targetzone='Groom Lake', type='surface'})
})

zones.groomlake:addGroups({
	GroupCommander:new({name='redgroomlakePatrol', mission='patrol', targetzone='Groom Lake'}),
	GroupCommander:new({name='redgroomlakecreechAttack', mission='attack', targetzone='Creech'}),
	GroupCommander:new({name='redgroomlakealamocharlieAttack', mission='attack', targetzone='Alamo Charlie'}),
	GroupCommander:new({name='redgroomlakecreechResupply', mission='supply', targetzone='Creech'}),
	GroupCommander:new({name='redgroomlakepahutemesaResupply', mission='supply', targetzone='Pahute Mesa'}),
	GroupCommander:new({name='redgroomlakecoyotecharlieResupply', mission='supply', targetzone='Coyote Charlie'}),
	GroupCommander:new({name='redgroomlakelincolncountyResupply', mission='supply', targetzone='Lincoln County'}),
	GroupCommander:new({name='bluegroomlakecreechResupply', mission='supply', targetzone='Creech'}),
	GroupCommander:new({name='bluegroomlakepahutemesaResupply', mission='supply', targetzone='Pahute Mesa'}),
	GroupCommander:new({name='bluegroomlakecoyotecharlieResupply', mission='supply', targetzone='Coyote Charlie'}),
	GroupCommander:new({name='bluegroomlakelincolncountyResupply', mission='supply', targetzone='Lincoln County'})
})

zones.coyotecharlie:addGroups({
	GroupCommander:new({name='redcoyotecharlielincolncountyResupply', mission='supply', targetzone='Lincoln County'}),
	GroupCommander:new({name='bluecoyotecharlielincolncountyResupply', mission='supply', targetzone='Lincoln County'}),
	GroupCommander:new({name='redcoyotecharliegroomlakeSurfAttack', mission='attack', targetzone='Groom Lake', type='surface'})
})

zones.tonopahtestrng:addGroups({
	GroupCommander:new({name='redtonopahtestrngtonopahResupply', mission='supply', targetzone='Tonopah'}),
	GroupCommander:new({name='redtonopahtestrngcoyotecharlieResupply', mission='supply', targetzone='Coyote Charlie'}),
	GroupCommander:new({name='bluetonopahtestrngtonopahResupply', mission='supply', targetzone='Tonopah'}),
	GroupCommander:new({name='bluetonopahtestrngcoyotecharlieResupply', mission='supply', targetzone='Coyote Charlie'})
})

zones.tonopah:addGroups({
	GroupCommander:new({name='redtonopahPatrol', mission='patrol', targetzone='Tonopah'}),
	GroupCommander:new({name='redtonopahtonopahtestrngResupply', mission='supply', targetzone='Tonopah Test Range'}),
	GroupCommander:new({name='redtonopahminaResupply', mission='supply', targetzone='Mina'}),
	GroupCommander:new({name='bluetonopahtonopahtestrngResupply', mission='supply', targetzone='Tonopah Test Range'}),
	GroupCommander:new({name='bluetonopahminaResupply', mission='supply', targetzone='Mina'}),
	GroupCommander:new({name='redtonopahtonopahtestrngSurfAttack', mission='attack', targetzone='Tonopah Test Range', type='surface'})
})

zones.mina:addGroups({
	GroupCommander:new({name='redminaPatrol', mission='patrol', targetzone='Mina'}),
	GroupCommander:new({name='redminatonopahSurfAttack', mission='attack', targetzone='Tonopah', type='surface'})
})

zones.lincolncounty:addGroups({
	GroupCommander:new({name='redlincolncountyPatrol', mission='patrol', targetzone='Lincoln County'}),
	GroupCommander:new({name='redlincolncountymesquiteResupply', mission='supply', targetzone='Mesquite'})
	
})

zones.mesquite:addGroups({
	GroupCommander:new({name='redmesquitePatrol', mission='patrol', targetzone='Mesquite'})
})

--Critical objects


--adds visible lines of "connection" between related zones
for i,v in pairs(zones) do
	bc:addZone(v)
end

bc:addConnection("McCarran International","Jean")
bc:addConnection("McCarran International","Henderson Executive")
bc:addConnection("McCarran International","Boulder City")
bc:addConnection("McCarran International","Hoover Dam")
bc:addConnection("Nellis AFB","McCarran International")
bc:addConnection("Nellis AFB","N Las Vegas")
bc:addConnection("Nellis AFB","X-Ray")
bc:addConnection("N Las Vegas","McCarran International")
bc:addConnection("N Las Vegas","Nellis AFB")
bc:addConnection("N Las Vegas","Creech")
bc:addConnection("Jean","Laughlin")
bc:addConnection("Creech","Alamo Charlie")
bc:addConnection("Creech","Beatty")
bc:addConnection("Groom Lake","Creech")
bc:addConnection("Groom Lake","Pahute Mesa")
bc:addConnection("Groom Lake","Coyote Charlie")
bc:addConnection("Groom Lake","Lincoln County")
bc:addConnection("Tonopah","Tonopah Test Range")
bc:addConnection("Tonopah","Mina")
bc:addConnection("Tonopah Test Range","Tonopah")
bc:addConnection("Tonopah Test Range","Coyote Charlie")
bc:addConnection("Coyote Charlie","Lincoln County")
bc:addConnection("X-Ray","Mesquite")
bc:addConnection("X-Ray","Alamo Charlie")
bc:addConnection("Hoover Dam","Mesquite")
bc:addConnection("Boulder City","Laughlin")
bc:addConnection("FARP Dallas","Jean")
bc:addConnection("Lincoln County","Mesquite")

--Mission complete msg
local checkMissionComplete = function (event, sender)
	local done = true
	for i,v in ipairs(bc:getZones()) do
		if v.side == 1 then
			done = false
			break
		end
	end
	
	if done then
		trigger.action.setUserFlag("ending", true)
		timer.scheduleFunction(endMission, {}, timer.getTime() + 20)
	end
end

for i,v in ipairs(bc:getZones()) do
	v:registerTrigger('lost', checkMissionComplete, 'missioncompleted')
end

--Disabling/losing zones (grayed out on map)


--F10 Menu Items
local upgradeMenu = nil
bc:registerShopItem('supplies', 'Resupply friendly Zone', 200, function(sender)
	if upgradeMenu then
		return 'Choose zone from F10 menu'
	end
	
	local upgradeZone = function(target)
		if upgradeMenu then
			local zn = bc:getZoneByName(target)
			if zn and zn.side==2 then
				zn:upgrade()
			else
				return 'Zone not friendly'
			end
			
			upgradeMenu = nil
		end
	end
	
	upgradeMenu = bc:showTargetZoneMenu(2, 'Select Zone to resupply', upgradeZone, 2)
	
	trigger.action.outTextForCoalition(2, 'Supplies prepared. Choose zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		params.zone:upgrade()
	else
		return 'Can only target friendly zone'
	end
end)

Group.getByName('capNorth'):destroy()
bc:registerShopItem('capN', 'CAP North (F-15C)', 150, function(sender) 
	local grname = 'capNorth'
	local gr = Group.getByName(grname)
	if Utils.isGroupActive(gr) then 
		return 'CAP mission still in progress'
	end
	mist.respawnGroup(grname, true)
end)

Group.getByName('capSouth'):destroy()
bc:registerShopItem('capS', 'CAP South (F-16C)', 150, function(sender) 
	local grname = 'capSouth'
	local gr = Group.getByName(grname)
	if Utils.isGroupActive(gr) then 
		return 'CAP mission still in progress'
	end
	mist.respawnGroup(grname, true)
end)

local spawnAwacs = function(sender) 
	local gr = Group.getByName('AWACS')
	if Utils.isGroupActive(gr) then 
		return 'Overlord still active on 350.00 MHz AM'
	end
	mist.respawnGroup('AWACS', true)
	trigger.action.outTextForCoalition(2,'Overlord active on 350.00 MHz AM',15)
end
Group.getByName('AWACS'):destroy()
bc:registerShopItem('AWACS', 'AWACS (E-3A)', 100, spawnAwacs, spawnAwacs)

Group.getByName('casSouth'):destroy()
local casTargetMenu = nil
bc:registerShopItem('casS', 'CAS South (A-10CII)', 400, function(sender) 
	local gr = Group.getByName('casSouth')
	if Utils.isGroupActive(gr) then 
		return 'Ground attack mission still in progress'
	end
	
	mist.respawnGroup('casSouth', true)
	
	if casTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if casTargetMenu then
			if Group.getByName('casSouth') then
				local err = bc:engageZone(target, 'casSouth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			casTargetMenu = nil
		end
	end
	
	casTargetMenu = bc:showTargetZoneMenu(2, 'CAS South Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'A-10CII Warthogs on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('casSouth')
		if Utils.isGroupActive(gr) then 
			return 'Ground attack mission still in progress'
		end
		
		mist.respawnGroup('casSouth', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('casSouth') then
				local err = bc:engageZone(target, 'casSouth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('casNorth'):destroy()
local casTargetMenu = nil
bc:registerShopItem('casN', 'CAS North (A-10CII)', 400, function(sender) 
	local gr = Group.getByName('casNorth')
	if Utils.isGroupActive(gr) then 
		return 'Ground attack mission still in progress'
	end
	
	mist.respawnGroup('casNorth', true)
	
	if casTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if casTargetMenu then
			if Group.getByName('casNorth') then
				local err = bc:engageZone(target, 'casNorth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			casTargetMenu = nil
		end
	end
	
	casTargetMenu = bc:showTargetZoneMenu(2, 'CAS North Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'A-10CII Warthogs on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('casNorth')
		if Utils.isGroupActive(gr) then 
			return 'Ground attack mission still in progress'
		end
		
		mist.respawnGroup('casNorth', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('casNorth') then
				local err = bc:engageZone(target, 'casNorth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('bombingNorth'):destroy()
local bomberTargetMenu = nil
bc:registerShopItem('bombN', 'Bombing run North (F-15E)', 600, function(sender) 
	local gr = Group.getByName('bombingNorth')
	if Utils.isGroupActive(gr) then 
		return 'Bombing run still in progress'
	end
	
	mist.respawnGroup('bombingNorth', true)
	
	if bomberTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if bomberTargetMenu then
			local bomb = Group.getByName('bombingNorth')
			if bomb then
				local err = bc:engageZone(target, 'bombingNorth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhens engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			bomberTargetMenu = nil
		end
	end
	
	bomberTargetMenu = bc:showTargetZoneMenu(2, 'Bombing run North Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F-15E Mudhens on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('bombingNorth')
		if Utils.isGroupActive(gr) then 
			return 'Bombing run still in progress'
		end
		
		mist.respawnGroup('bombingNorth', true)
		
		mist.scheduleFunction(function(target)
			local bomb = Group.getByName('bombingNorth')
			if bomb then
				local err = bc:engageZone(target, 'bombingNorth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhens engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('bombingSouth'):destroy()
local bomberTargetMenu = nil
bc:registerShopItem('bombS', 'Bombing run South (F-15E)', 600, function(sender) 
	local gr = Group.getByName('bombingSouth')
	if Utils.isGroupActive(gr) then 
		return 'Bombing run still in progress'
	end
	
	mist.respawnGroup('bombingSouth', true)
	
	if bomberTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if bomberTargetMenu then
			local bomb = Group.getByName('bombingSouth')
			if bomb then
				local err = bc:engageZone(target, 'bombingSouth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhens engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			bomberTargetMenu = nil
		end
	end
	
	bomberTargetMenu = bc:showTargetZoneMenu(2, 'Bombing run South Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F-15E Mudhens on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('bombingSouth')
		if Utils.isGroupActive(gr) then 
			return 'Bombing run still in progress'
		end
		
		mist.respawnGroup('bombingSouth', true)
		
		mist.scheduleFunction(function(target)
			local bomb = Group.getByName('bombingSouth')
			if bomb then
				local err = bc:engageZone(target, 'bombingSouth')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhens engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('seadS'):destroy()
local seadTargetMenu = nil
bc:registerShopItem('seadS', 'SEAD South (F/A-18C)', 150, function(sender) 
	local gr = Group.getByName('seadS')
	if Utils.isGroupActive(gr) then 
		return 'SEAD mission still in progress'
	end
	mist.respawnGroup('seadS', true)
	
	if seadTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if Group.getByName('seadS') then
			local err = bc:engageZone(target, 'seadS', AI.Task.WeaponExpend.ALL)
			if err then
				return err
			end
			
			trigger.action.outTextForCoalition(2, 'F/A-18c Hornets engaging SAMs at '..target, 15)
		else
			trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
		end
		
		seadTargetMenu = nil
	end
	
	seadTargetMenu = bc:showTargetZoneMenu(2, 'SEAD Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F/A-18c Hornets on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('seadS')
		if Utils.isGroupActive(gr) then 
			return 'SEAD mission still in progress'
		end
		
		mist.respawnGroup('seadS', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('seadS') then
				local err = bc:engageZone(target, 'seadS')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F/A-a8c Hornets engaging SAMs at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('seadN'):destroy()
local seadTargetMenu = nil
bc:registerShopItem('seadN', 'SEAD North (F/A-18C)', 150, function(sender) 
	local gr = Group.getByName('seadN')
	if Utils.isGroupActive(gr) then 
		return 'SEAD mission still in progress'
	end
	mist.respawnGroup('seadN', true)
	
	if seadTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if Group.getByName('seadN') then
			local err = bc:engageZone(target, 'seadN', AI.Task.WeaponExpend.ALL)
			if err then
				return err
			end
			
			trigger.action.outTextForCoalition(2, 'F/A-18c Hornets engaging SAMs at '..target, 15)
		else
			trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
		end
		
		seadTargetMenu = nil
	end
	
	seadTargetMenu = bc:showTargetZoneMenu(2, 'SEAD Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F/A-18c Hornets on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('seadN')
		if Utils.isGroupActive(gr) then 
			return 'SEAD mission still in progress'
		end
		
		mist.respawnGroup('seadN', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('seadN') then
				local err = bc:engageZone(target, 'seadN')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F/A-a8c Hornets engaging SAMs at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('jtacDrone-Lase-1688'):destroy()
local jtacTargetMenu = nil
drone = JTAC:new({name = 'jtacDrone-Lase-1688'})
bc:registerShopItem('jtac', 'MQ-9 Reaper JTAC mission', 100, function(sender)
	
	if jtacTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local spawnAndOrbit = function(target)
		if jtacTargetMenu then
			local zn = bc:getZoneByName(target)
			drone:deployAtZone(zn)
			drone:showMenu()
			trigger.action.outTextForCoalition(2, 'Reaper drone deployed over '..target, 15)
			jtacTargetMenu = nil
		end
	end
	
	jtacTargetMenu = bc:showTargetZoneMenu(2, 'Deploy JTAC', spawnAndOrbit, 1)
	
	trigger.action.outTextForCoalition(2, 'Choose which zone to deploy JTAC at from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		drone:deployAtZone(params.zone)
		drone:showMenu()
		trigger.action.outTextForCoalition(2, 'Reaper drone deployed over '..params.zone.zone, 15)
	else
		return 'Can only target enemy zone'
	end
end)

local smoketargets = function(tz)
	local units = {}
	for i,v in pairs(tz.built) do
		local g = Group.getByName(v)
		for i2,v2 in ipairs(g:getUnits()) do
			table.insert(units, v2)
		end
	end
	
	local tgts = {}
	for i=1,3,1 do
		if #units > 0 then
			local selected = math.random(1,#units)
			table.insert(tgts, units[selected])
			table.remove(units, selected)
		end
	end
	
	for i,v in ipairs(tgts) do
		local pos = v:getPosition().p
		trigger.action.smoke(pos, 1)
	end
end

local smokeTargetMenu = nil
bc:registerShopItem('smoke', 'Smoke markers', 20, function(sender)
	if smokeTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if smokeTargetMenu then
			local tz = bc:getZoneByName(target)
			smoketargets(tz)
			smokeTargetMenu = nil
			trigger.action.outTextForCoalition(2, 'Targets marked with RED smoke at '..target, 15)
		end
	end
	
	smokeTargetMenu = bc:showTargetZoneMenu(2, 'Smoke marker target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'Choose target zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		smoketargets(params.zone)
		trigger.action.outTextForCoalition(2, 'Targets marked with RED smoke at '..params.zone.zone, 15)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('Growler'):destroy()
local jamMenu = nil
bc:registerShopItem('jam', 'Jam radars at zone', 500, function(sender)
	local gr = Group.getByName('Growler')
	if Utils.isGroupActive(gr) then 
		return 'Jamming mission still in progress'
	end
	
	mist.respawnGroup('Growler', true)
	
	if jamMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local startJam = function(target)
		if jamMenu then
			bc:jamRadarsAtZone('Growler', target)
			jamMenu = nil
			trigger.action.outTextForCoalition(2, 'Growler jamming radars at '..target, 15)
		end
	end
	
	jamMenu = bc:showTargetZoneMenu(2, 'Jamming target', startJam, 1)
	trigger.action.outTextForCoalition(2, 'Choose target zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('Growler')
		if Utils.isGroupActive(gr) then 
			return 'Jamming mission still in progress'
		end
		
		mist.respawnGroup('Growler', true)
		
		mist.scheduleFunction(function(target)
			local ew = Group.getByName('Growler')
			if ew then
				local err = bc:jamRadarsAtZone('Growler', target)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'Growler jamming radars at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
		
	else
		return 'Can only target enemy zone'
	end
end)

tanksMenu = nil
bc:registerShopItem('armor', 'Deploy armor (for combined arms)', 100, function(sender)
	
	if tanksMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployTanks = function(target)
		if tanksMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-tanks')
			
			tanksMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly armor deployed at '..target, 15)
		end
	end
	
	tanksMenu = bc:showTargetZoneMenu(2, 'Deploy armor (Choose friendly zone)', deployTanks, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-tanks')
		trigger.action.outTextForCoalition(2, 'Friendly armor deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

artyMenu = nil
bc:registerShopItem('artillery', 'Deploy artillery (for combined arms)', 100, function(sender)
	
	if artyMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployArty = function(target)
		if artyMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-arty')
			
			artyMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly artillery deployed at '..target, 15)
		end
	end
	
	artyMenu = bc:showTargetZoneMenu(2, 'Deploy artillery (Choose friendly zone)', deployArty, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-arty')
		trigger.action.outTextForCoalition(2, 'Friendly artillery deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

reconMenu = nil
bc:registerShopItem('recon', 'Deploy recon group (for combined arms)', 50, function(sender)
	
	if reconMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployRecon = function(target)
		if reconMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-recon')
			
			reconMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly recon group deployed at '..target, 15)
		end
	end
	
	reconMenu = bc:showTargetZoneMenu(2, 'Deploy recon group (Choose friendly zone)', deployRecon, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-recon')
		trigger.action.outTextForCoalition(2, 'Friendly recon group deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

airdefMenu = nil
bc:registerShopItem('airdef', 'Deploy air defence (for combined arms)', 150, function(sender)
	
	if airdefMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployAirDef = function(target)
		if airdefMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-airdef')
			
			airdefMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly air defence deployed at '..target, 15)
		end
	end
	
	airdefMenu = bc:showTargetZoneMenu(2, 'Deploy air defence (Choose friendly zone)', deployAirDef, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-airdef')
		trigger.action.outTextForCoalition(2, 'Friendly air defence deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

bc:addShopItem(2, 'supplies', -1)
bc:addShopItem(2, 'jtac', -1)
bc:addShopItem(2, 'smoke', -1)
bc:addShopItem(2, 'jam', -1)

bc:addShopItem(2, 'casN', -1)
bc:addShopItem(2, 'bombN', -1)
bc:addShopItem(2, 'capN', -1)
bc:addShopItem(2, 'AWACS', -1)
bc:addShopItem(2, 'seadS', -1)
bc:addShopItem(2, 'seadN', -1)

bc:addShopItem(2, 'casS', -1)
bc:addShopItem(2, 'bombS', -1)
bc:addShopItem(2, 'capS', -1)

bc:addShopItem(2, 'armor', -1)
bc:addShopItem(2, 'artillery', -1)
bc:addShopItem(2, 'recon', -1)
bc:addShopItem(2, 'airdef', -1)

supplyZones = {
	'McCarran International', 
	'Nellis AFB', 
	'N Las Vegas', 
	'Jean', 
	'Creech', 
	'Groom Lake', 
	'Tonopah', 
	'Tonopah Test Range',
	'Coyote Charlie',
	'X-Ray',
	'Hoover Dam',
	'Boulder City',
	'FARP Dallas',
	'FARP London',
	'FARP Perth',
	'Laughlin',
	'Henderson Executive',
	'Beatty',
	'Pahute Mesa',
	'Mina',
	'Lincoln County',
	'Mesquite'
}

--logistics commander
lc = LogisticCommander:new({battleCommander = bc, supplyZones = supplyZones})
lc:init()

--Credit amounts for kills
bc:loadFromDisk() --will load and overwrite default zone levels, sides, funds and available shop items
bc:init()
bc:startRewardPlayerContribution(15,{infantry = 10, ground = 20, sam = 40, airplane = 50, ship = 250, helicopter=50, crate=200, rescue = 100})
HercCargoDropSupply.init(bc)

--GlobalSettings.defaultRespawns[1]['supply'] = { dead=60*60, hangar=30*60, preparing=5*60}
GlobalSettings.setDifficultyScaling(1.4,1)

--create event commander
evc = EventCommander:new({ decissionFrequency=15*60, decissionVariance=15*60, skipChance = 5}) --decissionFrequency=30*60, decissionVariance=30*60, skipChance = 10
evc:init()

--MIST spawns of events
Group.getByName('evt-cargointercept'):destroy()
Group.getByName('evt-cargointercept-1'):destroy()
Group.getByName('evt-cargointercept-2'):destroy()

local cargoDieEvent = nil
evc:addEvent({
	id='cargointercept',
	action = function()
	
		local planes = {'evt-cargointercept','evt-cargointercept-1','evt-cargointercept-2'}
		local choice = math.random(1,#planes)
		
		mist.respawnGroup(planes[choice], true)
		
		local cargoDie = function(event)
			if event.id==30 then
				if event.initiator and event.initiator.getName then
					local name = event.initiator:getName()
					if type(name)=="string" and name:find('^evt%-cargointercept') then
						mist.removeEventHandler(cargoDieEvent)
						cargoDieEvent = nil
						trigger.action.outTextForCoalition(2,'Enemy cargo plane destroyed.\n+500 credits',15)
						bc:addFunds(2,500)
					end
				end
			end
		end
		cargoDieEvent = mist.addEventHandler(cargoDie)
	end,
	canExecute = function()
		if math.random(1,100) < 70 then return false end
		
		if bc:getZoneByName('Tonopah Test Range').side ~= 1 then return false end
		
		if Group.getByName('evt-cargointercept') then return false end
		if Group.getByName('evt-cargointercept-1') then return false end
		if Group.getByName('evt-cargointercept-2') then return false end
		
		return true
	end
})

attacknellisafb = {
	['Creech'] = { 'evt-creech-nellisafb-arty'}
}
for i,v in pairs(attacknellisafb) do
	for _,v2 in ipairs(v) do
		Group.getByName(v2):destroy()
	end
end
evc:addEvent({
	id='nellisafbattack',
	action = function()
		for i,v in pairs(attacknellisafb) do
			if bc:getZoneByName(i).side == 1 then
				for _,v2 in ipairs(v) do
					mist.respawnGroup(v2, true)
				end
			end
		end
	end,
	canExecute = function()
		if math.random(1,100) < 60 then return false end
		
		if bc:getZoneByName('Nellis AFB').side ~= 2 then return false end
		
		local canAttack = false
		for i,v in pairs(attacknellisafb) do
			if bc:getZoneByName(i).side == 1 then canAttack = true end
			
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return false end
			end
		end
		
		return canAttack
	end
})

attackmccarranintl = {
	['Creech'] = { 'evt-creech-mccarranintl-arty'}
}
for i,v in pairs(attackmccarranintl) do
	for _,v2 in ipairs(v) do
		Group.getByName(v2):destroy()
	end
end
evc:addEvent({
	id='mccarranintlattack',
	action = function()
		for i,v in pairs(attackmccarranintl) do
			if bc:getZoneByName(i).side == 1 then
				for _,v2 in ipairs(v) do
					mist.respawnGroup(v2, true)
				end
			end
		end
	end,
	canExecute = function()
		if math.random(1,100) < 60 then return false end
		
		if bc:getZoneByName('McCarran International').side ~= 2 then return false end
		
		local canAttack = false
		for i,v in pairs(attackmccarranintl) do
			if bc:getZoneByName(i).side == 1 then canAttack = true end
			
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return false end
			end
		end
		
		return canAttack
	end
})

attacktonopahtestrng = {
	['Mina'] = { 'evt-mina-tonopahtestrng-scuds'}
}
for i,v in pairs(attacktonopahtestrng) do
	for _,v2 in ipairs(v) do
		Group.getByName(v2):destroy()
	end
end
evc:addEvent({
	id='tonopahtestrngattack',
	action = function()
		for i,v in pairs(attacktonopahtestrng) do
			if bc:getZoneByName(i).side == 1 then
				for _,v2 in ipairs(v) do
					mist.respawnGroup(v2, true)
				end
			end
		end
	end,
	canExecute = function()
		if math.random(1,100) < 60 then return false end
		
		if bc:getZoneByName('Tonopah Test Range').side ~= 2 then return false end
		
		local canAttack = false
		for i,v in pairs(attacktonopahtestrng) do
			if bc:getZoneByName(i).side == 1 then canAttack = true end
			
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return false end
			end
		end
		
		return canAttack
	end
})

Group.getByName('evt-bomber'):destroy()
evc:addEvent({
	id='bomb',
	action = function()
		mist.respawnGroup('evt-bomber', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-bomber')
		if gr then return false end
		
		local triggers = {'Jean', 'Henderson Executive', 'Boulder City', 'McCarran International'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startBomberAttack() -- called from bomber groups waypoint actions
	local tgts = {
		'McCarran International',
		'N Las Vegas',
		'Nellis AFB',
		'Creech',
		'Pahute Mesa',
		'Groom Lake',
		'Tonopah Test Range',
		'Tonopah',
		'Henderson Executive',
		'Boulder City',
		'Hoover Dam'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-bomber') then
			bc:engageZone(choice, 'evt-bomber',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-sead'):destroy()
evc:addEvent({
	id='sead',
	action = function()
		mist.respawnGroup('evt-sead', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-sead')
		if gr then return false end
		
		local triggers = {'McCarran International', 'Nellis AFB'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startSEADAttack() -- called from SEAD groups waypoint actions
	local tgts = {
		'McCarran International',
		'Nellis AFB',
		'Tonopah',
		'Creech',
		'Groom Lake',
		'Lincoln County',
		'Tonopah Test Range'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-sead') then
			bc:engageZone(choice, 'evt-sead',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-cas'):destroy()
evc:addEvent({
	id='cas',
	action = function()
		mist.respawnGroup('evt-cas', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-cas')
		if gr then return false end
		
		local triggers = {'Henderson Executive', 'Boulder City'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCASAttack() -- called from CAS groups waypoint actions
	local tgts = {
		'Laughlin',
		'Jean',
		'Henderson Executive',
		'Boulder City',
		'Hoover Dam',
		'McCarran International',
		'N Las Vegas',
		'Nellis AFB',
		'X-Ray',
		'Creech',
		'Mesquite'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-cas') then
			bc:engageZone(choice, 'evt-cas',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-cas-1'):destroy()
evc:addEvent({
	id='cas',
	action = function()
		mist.respawnGroup('evt-cas-1', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-cas-1')
		if gr then return false end
		
		local triggers = {'Pahute Mesa', 'Groom Lake'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCAS1Attack() -- called from CAS1 groups waypoint actions
	local tgts = {
		'Beatty',
		'Pahute Mesa',
		'Groom Lake',
		'Lincoln County',
		'Coyote Charlie',
		'Tonopah Test Range',
		'Tonopah',
		'Mina'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-cas-1') then
			bc:engageZone(choice, 'evt-cas-1',  AI.Task.WeaponExpend.ALL)
		end
	end
end

-- System msgs for events triggered
mc = MissionCommander:new({side = 2, battleCommander = bc, checkFrequency = 20}) --was checkFrequency = 60
mc:trackMission({
	title = "Intercept cargo plane",
	description = "Find and destroy the enemy cargo plane.",
	messageStart = "New mission: Intercept cargo plane",
	messageEnd = "Mission ended: Intercept cargo plane",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		if Group.getByName('evt-cargointercept') then return true end
		if Group.getByName('evt-cargointercept-1') then return true end
		if Group.getByName('evt-cargointercept-2') then return true end
		
		return false
	end
})

mc:trackMission({
	title = "Defend McCarran International",
	description = "The enemy is preparing an attack on McCarran International.",
	messageStart = "New mission: Defend McCarran International",
	messageEnd = "Mission ended: Defend McCarran International",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		for i,v in pairs(attackmccarranintl) do
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return true end
			end
		end
		
		return false
	end
})

mc:trackMission({
	title = "Defend Nellis AFB",
	description = "The enemy is preparing an attack on Nellis AFB.",
	messageStart = "New mission: Defend Nellis AFB",
	messageEnd = "Mission ended: Defend Nellis AFB",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		for i,v in pairs(attacknellisafb) do
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return true end
			end
		end
		
		return false
	end
})

mc:trackMission({
	title = "Defend Tonopah Test Range",
	description = "The enemy is preparing an attack on Tonopah Test Range.",
	messageStart = "New mission: Defend Tonopah Test Range",
	messageEnd = "Mission ended: Defend Tonopah Test Range",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		for i,v in pairs(attacktonopahtestrng) do
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return true end
			end
		end
		
		return false
	end
})

mc:trackMission({
	title = "Intercept Bombers",
	description = "Enemy bombers spotted to the north-west\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept Bombers",
	messageEnd = "Mission ended: Intercept Bombers",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-bomber')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept enemy airstrike",
	description = "Enemy aircraft conducting an airstrike from the south-east\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept enemy airstrike",
	messageEnd = "Mission ended: Intercept enemy airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-cas')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept enemy airstrike",
	description = "Enemy aircraft conducting an airstrike from the north\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept enemy airstrike",
	messageEnd = "Mission ended: Intercept enemy airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-cas-1')
		if gr then return true else return false end
	end
})

resupplyTarget = nil
mc:trackMission({
	title = function() return "Resupply "..resupplyTarget end,
	description = function() return "Deliver supplies to "..resupplyTarget end,
	messageStart = function() return "New mission: Resupply "..resupplyTarget end,
	messageEnd = function() return "Mission ended: Resupply "..resupplyTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		resupplyTarget = nil
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not resupplyTarget then return false end
		
		local targetzn = bc:getZoneByName(resupplyTarget)
		return targetzn:canRecieveSupply()
	end
})

attackTarget = nil
mc:trackMission({
	title = function() return "Attack "..attackTarget end,
	description = function() return "Destroy enemy forces at "..attackTarget end,
	messageStart = function() return "New mission: Attack "..attackTarget end,
	messageEnd = function() return "Mission ended: Attack "..attackTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		attackTarget = nil 
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not attackTarget then return false end
		
		local targetzn = bc:getZoneByName(attackTarget)
		return targetzn.side == 1
	end
})

captureTarget = nil
mc:trackMission({
	title = function() return "Capture "..captureTarget end,
	description = function() return captureTarget.." is neutral. Capture it by delivering supplies" end,
	messageStart = function() return "New mission: Capture "..captureTarget end,
	messageEnd = function() return "Mission ended: Capture "..captureTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		captureTarget = nil 
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not captureTarget then return false end
		
		local targetzn = bc:getZoneByName(captureTarget)
		return targetzn.side == 0 and targetzn.active
	end
})

--Functions/

function addFunds250()
	bc:addFunds(2,250)
	end
	
function addFunds500()
	bc:addFunds(2,500)
	end
	
function addSpecialFunds500()
	bc:addFunds(2,500)
	end
	
function endMission()
	--trigger.action.outTextForCoalition(2, 'file path is '..pathofFile, 420)
	--io.close(pathofFile)
	--timer.scheduleFunction(delFile, {}, timer.getTime() + 10)
	--os.remove(pathofFile)
	trigger.action.setUserFlag("endMission", true)
	end
	
function generateCaptureMission()
	if captureTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.zones) do
		if v.side == 0 and v.active and v.zone ~= "FARP Dallas" and v.zone ~= "FARP Perth" and v.zone ~= "FARP London" then
			table.insert(validzones, v.zone)
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		captureTarget = validzones[choice]
		return true
	end
end

function generateAttackMission()
	if attackTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.connections) do
		local to = bc:getZoneByName(v.to)
		local from = bc:getZoneByName(v.from)
		
		if from.side ~= to.side and from.side ~= 0  and to.side ~= 0 and from.active and to.active then
			if from.side == 1 then
				table.insert(validzones, from.zone)
			elseif to.side == 1 then
				table.insert(validzones, to.zone)
			end
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		attackTarget = validzones[choice]
		return true
	end
end

function generateSupplyMission()
	if resupplyTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.zones) do
		if v.side == 2 and v:canRecieveSupply() then
			table.insert(validzones, v.zone)
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		resupplyTarget = validzones[choice]
		return true
	end
end

timer.scheduleFunction(function(_, time)
	if generateCaptureMission() then
		return time+300
	else
		return time+120
	end
end, {}, timer.getTime() + 20)

timer.scheduleFunction(function(_, time)
	if generateAttackMission() then
		return time+300
	else
		return time+120
	end
end, {}, timer.getTime() + 40)

timer.scheduleFunction(function(_, time)
	if generateSupplyMission() then
		return time+480
	else
		return time+240
	end
end, {}, timer.getTime() + 60)

mc:init()